==> zio-aws-lakeformation_2.13-5.17.155.1-sources.jar: zio/aws/lakeformation/model/DeleteLfTagRequest.scala <==
package zio.aws.lakeformation.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.lakeformation.model.primitives.{LFTagKey, CatalogIdString}
import scala.jdk.CollectionConverters._
final case class DeleteLfTagRequest(
    catalogId: Option[CatalogIdString] = None,
    tagKey: LFTagKey
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lakeformation.model.DeleteLfTagRequest = {
    import DeleteLfTagRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lakeformation.model.DeleteLfTagRequest
      .builder()
      .optionallyWith(
        catalogId.map(value => CatalogIdString.unwrap(value): java.lang.String)
      )(_.catalogId)
      .tagKey(LFTagKey.unwrap(tagKey): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.lakeformation.model.DeleteLfTagRequest.ReadOnly =
    zio.aws.lakeformation.model.DeleteLfTagRequest.wrap(buildAwsValue())
}
object DeleteLfTagRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lakeformation.model.DeleteLfTagRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lakeformation.model.DeleteLfTagRequest =
      zio.aws.lakeformation.model
        .DeleteLfTagRequest(catalogId.map(value => value), tagKey)
    def catalogId: Option[CatalogIdString]
    def tagKey: LFTagKey
    def getCatalogId: ZIO[Any, AwsError, CatalogIdString] =
      AwsError.unwrapOptionField("catalogId", catalogId)
    def getTagKey: ZIO[Any, Nothing, LFTagKey] = ZIO.succeed(tagKey)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lakeformation.model.DeleteLfTagRequest
  ) extends zio.aws.lakeformation.model.DeleteLfTagRequest.ReadOnly {
    override val catalogId: Option[CatalogIdString] = scala
      .Option(impl.catalogId())
      .map(value =>
        zio.aws.lakeformation.model.primitives.CatalogIdString(value)
      )
    override val tagKey: LFTagKey =
      zio.aws.lakeformation.model.primitives.LFTagKey(impl.tagKey())
  }
  def wrap(
      impl: software.amazon.awssdk.services.lakeformation.model.DeleteLfTagRequest
  ): zio.aws.lakeformation.model.DeleteLfTagRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-lakeformation_2.13-5.17.203.2-sources.jar: zio/aws/lakeformation/model/DeleteLfTagRequest.scala <==
package zio.aws.lakeformation.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.lakeformation.model.primitives.{LFTagKey, CatalogIdString}
import scala.jdk.CollectionConverters._
final case class DeleteLfTagRequest(
    catalogId: Optional[CatalogIdString] = Optional.Absent,
    tagKey: LFTagKey
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lakeformation.model.DeleteLfTagRequest = {
    import DeleteLfTagRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lakeformation.model.DeleteLfTagRequest
      .builder()
      .optionallyWith(
        catalogId.map(value => CatalogIdString.unwrap(value): java.lang.String)
      )(_.catalogId)
      .tagKey(LFTagKey.unwrap(tagKey): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.lakeformation.model.DeleteLfTagRequest.ReadOnly =
    zio.aws.lakeformation.model.DeleteLfTagRequest.wrap(buildAwsValue())
}
object DeleteLfTagRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lakeformation.model.DeleteLfTagRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lakeformation.model.DeleteLfTagRequest =
      zio.aws.lakeformation.model
        .DeleteLfTagRequest(catalogId.map(value => value), tagKey)
    def catalogId: Optional[CatalogIdString]
    def tagKey: LFTagKey
    def getCatalogId: ZIO[Any, AwsError, CatalogIdString] =
      AwsError.unwrapOptionField("catalogId", catalogId)
    def getTagKey: ZIO[Any, Nothing, LFTagKey] = ZIO.succeed(tagKey)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lakeformation.model.DeleteLfTagRequest
  ) extends zio.aws.lakeformation.model.DeleteLfTagRequest.ReadOnly {
    override val catalogId: Optional[CatalogIdString] = zio.aws.core.internal
      .optionalFromNullable(impl.catalogId())
      .map(value =>
        zio.aws.lakeformation.model.primitives.CatalogIdString(value)
      )
    override val tagKey: LFTagKey =
      zio.aws.lakeformation.model.primitives.LFTagKey(impl.tagKey())
  }
  def wrap(
      impl: software.amazon.awssdk.services.lakeformation.model.DeleteLfTagRequest
  ): zio.aws.lakeformation.model.DeleteLfTagRequest.ReadOnly = new Wrapper(impl)
}
